==> react-ui-library-0.0.30.tgz: package/src/components/BottomSheet.js <==
import React, { Component, PropTypes } from 'react'
import styled, { css, keyframes } from 'styled-components'
import Box from './Box'
import Pane from './Pane'
import Overlay from './Overlay'
import Close from './Close'
import Button from './Button'
import { WhiteNavigationBar } from './NavigationBar'

const BottomSheetHeader = ({ ...props}) =>
  <Pane
    white
    shadow
    {...props} />

const slideInAnimation = keyframes`
  from {
    transform: translateY(100%);
  }
  to {
    transform: translateY(0);
  }
`
const slideOutAnimation = keyframes`
  from {
    transform: translateY(0);
  }
  to {
    transform: translateY(100%);
  }
`

const styles = ({ slideOut, theme }) => css`
  transform: translateZ(0);
  animation: ${slideOut ? slideOutAnimation : slideInAnimation } ${theme.animationDuration.slow} ${theme.animationEasing.deceleration};
`

const BottomSheetPane = styled(({ slideOut, ...props }) =>
  <Pane
    tint
    position='absolute'
    shadow
    height='100vh'
    left={0}
    right={0}
    bottom={0}
    {...props} />)`${styles}`

BottomSheetPane.propTypes = {
  slideOut: PropTypes.bool
}

BottomSheetPane.displayName = 'BottomSheetPane'

class BottomSheet extends Component {
  constructor() {
    super()

    this.handleClose = this.handleClose.bind(this)
    this.handleAnimationEnd = this.handleAnimationEnd.bind(this)

    this.state = {
      isClosing: false
    }
  }

  handleClose() {
    console.log('handleClose')
    this.setState({ isClosing: true })
  }

  handleAnimationEnd() {
    if (!this.state.isClosing) return
    this.props.onClose()
    this.setState({ isClosing: false })
  }

  render() {
    const {
      onClose,
      isOpen,
      children,
      navigationBarLeft,
      navigationBarRight,
      navigationBarChildren,
      ...props
    } = this.props

    const { isClosing } = this.state

    if (!isOpen) return null

    return (
      <Overlay onClick={this.handleClose} fadeOut={isClosing} onAnimationEnd={this.handleAnimationEnd}>
        <BottomSheetPane onClick={(e) => e.stopPropagation()} slideOut={isClosing} {...props}>
          <WhiteNavigationBar left={navigationBarLeft} right={React.cloneElement(navigationBarRight, { onClick: this.handleClose })}>
            {navigationBarChildren}
          </WhiteNavigationBar>
          {children}
        </BottomSheetPane>
      </Overlay>
    )
  }
}

const CloseButton = (props) => <Button {...props}>Cancel</Button>

BottomSheet.propTypes = {
  isOpen: PropTypes.bool,
  onClose: PropTypes.func,
  navigationBarLeft: PropTypes.node,
  navigationBarRight: PropTypes.node,
  navigationBarChildren: PropTypes.node
}

BottomSheet.defaultProps = {
  isOpen: true,
  navigationBarLeft: null,
  navigationBarRight: <CloseButton />,
  navigationBarChildren: null
}


BottomSheet.displayName = 'BottomSheet'

export default BottomSheet

==> react-ui-library-0.2.5.tgz: package/src/components/BottomSheet.js <==
import React, { Component, PropTypes } from 'react'
import styled, { css, keyframes } from 'styled-components'
import Box from './Box'
import Pane from './Pane'
import Overlay from './Overlay'
import Close from './Close'
import Text from './Text'
import Button from './Button'
import { WhiteNavigationBar } from './NavigationBar'

const BottomSheetTopBar = ({ left, right, children, ...props }) =>
  <Pane display='flex' alignItems='center' shadow white {...props}>
    <Pane width={4} height='100%' padding={3} display='flex'>{left}</Pane>
    <Pane flexAuto textAlign='center'>{children}</Pane>
    <Pane width={4} textAlign='right' padding={3}>{right}</Pane>
  </Pane>

BottomSheetTopBar.propTypes = {
  left: PropTypes.node,
  right: PropTypes.node
}

BottomSheetTopBar.displayName = 'BottomSheetTopBar'

const BottomSheetCloseButton = (props) => <Button paddingX={5} {...props}>Cancel</Button>

const slideInAnimation = keyframes`
  from {
    transform: translateY(100%);
  }
  to {
    transform: translateY(0);
  }
`
const slideOutAnimation = keyframes`
  from {
    transform: translateY(0);
  }
  to {
    transform: translateY(100%);
  }
`

const styles = ({ slideOut, theme }) => css`
  transform: translateZ(0);
  animation: ${slideOut ? slideOutAnimation : slideInAnimation } ${theme.animationDuration.slow} ${theme.animationEasing.deceleration};
`

const BottomSheetPane = styled(({ slideOut, ...props }) =>
  <Pane
    tint
    position='absolute'
    shadow
    height='100vh'
    left={0}
    right={0}
    bottom={0}
    {...props} />)`${styles}`

BottomSheetPane.propTypes = {
  slideOut: PropTypes.bool
}

BottomSheetPane.displayName = 'BottomSheetPane'

class BottomSheet extends Component {
  constructor() {
    super()

    this.handleClose = this.handleClose.bind(this)
    this.handleAnimationEnd = this.handleAnimationEnd.bind(this)

    this.state = {
      isClosing: false
    }
  }

  handleClose() {
    this.setState({ isClosing: true })
  }

  handleAnimationEnd() {
    if (!this.state.isClosing) return
    this.props.onClose()
    this.setState({ isClosing: false })
  }

  render() {
    const {
      onClose,
      isOpen,
      children,
      navigationBarLeft,
      navigationBarRight,
      title,
      ...props
    } = this.props

    const { isClosing } = this.state

    if (!isOpen) return null

    return (
      <Overlay onClick={this.handleClose} fadeOut={isClosing} onAnimationEnd={this.handleAnimationEnd}>
        <BottomSheetPane onClick={(e) => e.stopPropagation()} slideOut={isClosing} {...props}>
          <BottomSheetTopBar left={React.cloneElement(navigationBarLeft, { onClick: this.handleClose })} right={navigationBarRight}>
            <Text is='h2' textStyle='display3'>{title}</Text>
          </BottomSheetTopBar>
          {children}
        </BottomSheetPane>
      </Overlay>
    )
  }
}

BottomSheet.propTypes = {
  isOpen: PropTypes.bool,
  onClose: PropTypes.func,
  navigationBarLeft: PropTypes.node,
  navigationBarRight: PropTypes.node,
  title: PropTypes.string
}

BottomSheet.defaultProps = {
  isOpen: true,
  navigationBarLeft: <BottomSheetCloseButton />,
  navigationBarRight: null,
  title: null
}

BottomSheet.displayName = 'BottomSheet'

export default BottomSheet
